@@ -5,13 +5,10 @@ class Venue(models.Model):
     """A backstage Venue is a specific local install of backstage."""
     venue_name = models.TextField(max_length=80, primary_key=True)
     venue_path = models.TextField(max_length=255)
-    def __init__(self):
-        self.venue_root = os.path.abspath(os.path.join(self.venue_path, self.venue_name))
+    def __init__(self, venue_path, venue_name):
+        self.venue_root = os.path.abspath(os.path.join(venue_path, venue_name))
         self.UWSGI_INI = os.path.join(self.VENUE_ROOT, 'backstage-%s-uwsgi.ini' % (self.VENUE_NAME))
 
-    def __init__(self, venue_root):
-        """Initialize a Backstage Venue instance. Required arguments are the name of the venue and the fullpath of the venue (name included)
-        """
         if not os.path.exists(venue_root):
             print 'venue does not exist at %s' % (venue_root)
             raise
